@@ -2,13 +2,15 @@
 # -*- coding: utf-8 -*-
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 
 """Dialog classes for the Builder, including ParamCtrls
 """
 
 from __future__ import absolute_import, division, print_function
+import sys
+from pathlib import Path
 
 from builtins import map
 from builtins import str
@@ -21,11 +23,6 @@ import wx
 
 import psychopy.experiment.utils
 
-try:
-    from wx.lib.agw import flatnotebook
-except ImportError:  # was here wx<4.0:
-    from wx.lib import flatnotebook
-
 from ... import dialogs
 from .. import experiment
 from .. validators import NameValidator, CodeSnippetValidator
@@ -105,8 +102,7 @@ class ParamCtrls(object):
         label = _translate(label)
         if param.valType == 'code' and fieldName not in _nonCode:
             label += ' $'
-        self.nameCtrl = wx.StaticText(parent, -1, label, size=wx.DefaultSize,
-                                      style=wx.ALIGN_RIGHT)
+        self.nameCtrl = wx.StaticText(parent, -1, label, size=wx.DefaultSize)
 
         if fieldName == 'Use version':
             # _localVersionsCache is the default (faster) when creating
@@ -116,7 +112,8 @@ class ParamCtrls(object):
                 options = vc._versionFilter(vc.versionOptions(local=False), wx.__version__)
                 versions = vc._versionFilter(vc.availableVersions(local=False), wx.__version__)
                 param.allowedVals = (options + [''] + versions)
-        if fieldName in ['text', 'customize_everything', 'customize']:
+        if (param.valType == 'extendedStr'
+                or fieldName == 'text'):  # because text used to be 'str' until 2020.2
             # for text input we need a bigger (multiline) box
             if fieldName == 'customize_everything':
                 sx, sy = 300, 400
@@ -125,11 +122,8 @@ class ParamCtrls(object):
             else:
                 sx, sy = 100, 200
             # set viewer small, then it SHOULD increase with wx.aui control
-            self.valueCtrl = CodeBox(parent, -1, pos=wx.DefaultPosition,
-                                     size=wx.Size(sx, sy), style=0,
-                                     prefs=appPrefs)
-            if len(param.val):
-                self.valueCtrl.AddText(str(param.val))
+            self.valueCtrl = wx.TextCtrl(parent, -1, value=str(param.val), pos=wx.DefaultPosition,
+                                         size=wx.Size(sx, sy), style=wx.TE_MULTILINE)
             if fieldName == 'text':
                 self.valueCtrl.SetFocus()
         elif fieldName == 'Experiment info':
@@ -159,6 +153,12 @@ class ParamCtrls(object):
                                          name=fieldName,
                                          size=wx.Size(self.valueWidth, -1))
             self.valueCtrl.SetValue(param.val)
+        elif param.valType == 'fileList':
+            self.valueCtrl = FileListCtrl(parent,
+                                          choices=param.val,
+                                          size=wx.Size(self.valueWidth, 100),
+                                          pathtype="rel"
+                                          )
         elif len(param.allowedVals) > 1:
             # there are limited options - use a Choice control
             # use localized text or fall through to non-localized,
@@ -251,6 +251,9 @@ class ParamCtrls(object):
             self.updateCtrl = wx.Choice(parent, choices=updateLabels)
             # stash non-localized choices to allow retrieval by index:
             self.updateCtrl._choices = copy.copy(allowedUpdates)
+            # If parameter isn't in list, default to the first choice
+            if param.updates not in allowedUpdates:
+                param.updates = allowedUpdates[0]
             # get index of the currently set update value, set display:
             index = allowedUpdates.index(param.updates)
             # set by integer index, not string value
@@ -475,22 +478,24 @@ class _BaseParamsDlg(wx.Dialog):
 
         # create main sizer
         self.mainSizer = wx.BoxSizer(wx.VERTICAL)
-        agwStyle = flatnotebook.FNB_NO_X_BUTTON
-        if hasattr(flatnotebook, "FNB_NAV_BUTTONS_WHEN_NEEDED"):
-            # not available in wxPython 2.8
-            agwStyle |= flatnotebook.FNB_NAV_BUTTONS_WHEN_NEEDED
-        if hasattr(flatnotebook, "FNB_NO_TAB_FOCUS"):
-            # not available in wxPython 2.8.10
-            agwStyle |= flatnotebook.FNB_NO_TAB_FOCUS
-        self.ctrls = flatnotebook.FlatNotebook(self, style=agwStyle)
-        self.mainSizer.Add(self.ctrls,  # ctrls is the notebook of params
-                           proportion=1, flag=wx.EXPAND | wx.ALL, border=5)
-        categNames = sorted(categs)
-        if 'Basic' in categNames:
-            # move it to be the first category we see
-            categNames.insert(0, categNames.pop(categNames.index('Basic')))
-        # move into _localized after merge branches:
+
+        self.ctrls = wx.Notebook(self)
+
+        if self.__class__ != DlgExperimentProperties:
+            self.mainSizer.Add(self.ctrls,  # ctrls is the notebook of params
+                               proportion=1, flag=wx.EXPAND | wx.ALL, border=5)
+        # Sort category names
+        allCategNames = sorted(categs)
+        firstCategs = ['Basic', 'Appearance', 'Layout', 'Formatting', 'Texture', 'Data', 'Timing']
+        lastCategs = ['Custom', 'Hardware', 'Testing']
+        bonusCategs = [nm for nm in allCategNames if nm not in firstCategs+lastCategs]
+        categNames = [nm for nm in firstCategs if nm in allCategNames] \
+                     + bonusCategs \
+                     + [nm for nm in lastCategs if nm in allCategNames]
+
         categLabel = {'Basic': _translate('Basic'),
+                      'Color': _translate('Color'),
+                      'Layout': _translate('Layout'),
                       'Data': _translate('Data'),
                       'Screen': _translate('Screen'),
                       'Dots': _translate('Dots'),
@@ -503,10 +508,12 @@ class _BaseParamsDlg(wx.Dialog):
                       'Save': _translate('Save'),
                       'Online':_translate('Online'),
                       'Testing':_translate('Testing'),
-                      'Audio':_translate('Audio')}
+                      'Audio':_translate('Audio'),
+                      'Format':_translate('Format')}
         for categName in categNames:
             theseParams = categs[categName]
             page = wx.Panel(self.ctrls, -1)
+            page.app = self.app
             ctrls = self.addCategoryOfParams(theseParams, parent=page)
             if categName in categLabel:
                 cat = categLabel[categName]
@@ -672,8 +679,8 @@ class _BaseParamsDlg(wx.Dialog):
         startEstimSizer.Add(self.startEstimCtrl, flag=wx.ALIGN_BOTTOM)
         startAllCrtlSizer = wx.BoxSizer(orient=wx.VERTICAL)
         startAllCrtlSizer.Add(startSizer, flag=wx.EXPAND)
-        startAllCrtlSizer.Add(startEstimSizer, flag=wx.ALIGN_RIGHT)
-        sizer.Add(label, (currRow, 0), (1, 1), wx.ALIGN_RIGHT)
+        startAllCrtlSizer.Add(startEstimSizer)
+        sizer.Add(label, (currRow, 0), (1, 1))
         # add our new row
         sizer.Add(startAllCrtlSizer, (currRow, 1), (1, 1), flag=wx.EXPAND)
         currRow += 1
@@ -716,9 +723,8 @@ class _BaseParamsDlg(wx.Dialog):
                            flag=wx.ALIGN_CENTRE_VERTICAL)
         stopAllCrtlSizer = wx.BoxSizer(orient=wx.VERTICAL)
         stopAllCrtlSizer.Add(stopSizer, flag=wx.EXPAND)
-        stopAllCrtlSizer.Add(stopEstimSizer,
-                             flag=wx.ALIGN_RIGHT | wx.ALIGN_CENTRE_VERTICAL)
-        sizer.Add(label, (currRow, 0), (1, 1), wx.ALIGN_RIGHT)
+        stopAllCrtlSizer.Add(stopEstimSizer)
+        sizer.Add(label, (currRow, 0), (1, 1))
         # add our new row
         sizer.Add(stopAllCrtlSizer, (currRow, 1), (1, 1), flag=wx.EXPAND)
         currRow += 1
@@ -758,20 +764,27 @@ class _BaseParamsDlg(wx.Dialog):
             ctrls.valueCtrl.Bind(wx.EVT_KEY_UP, self.doValidate)
 
         # add the controls to the sizer
-        _flag = wx.ALIGN_RIGHT | wx.ALIGN_CENTRE_VERTICAL | wx.LEFT | wx.RIGHT
+        _flag = wx.LEFT | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL
         sizer.Add(ctrls.nameCtrl, (currRow, 0), border=5, flag=_flag)
         if ctrls.updateCtrl:
             sizer.Add(ctrls.updateCtrl, (currRow, 2), flag=_flag)
         if ctrls.typeCtrl:
             sizer.Add(ctrls.typeCtrl, (currRow, 3), flag=_flag)
         # different flag for the value control (expand)
-        _flag = wx.EXPAND | wx.ALIGN_CENTRE_VERTICAL | wx.ALL
-        sizer.Add(ctrls.valueCtrl, (currRow, 1), border=5, flag=_flag)
+        _flag = wx.EXPAND | wx.ALL
+        if hasattr(ctrls.valueCtrl, '_szr'):
+            sizer.Add(ctrls.valueCtrl._szr, (currRow, 1), border=5, flag=_flag)
+        else:
+            sizer.Add(ctrls.valueCtrl, (currRow, 1), border=5, flag=_flag)
 
         # use monospace font to signal code:
         if fieldName != 'name' and hasattr(ctrls.valueCtrl, 'GetFont'):
             if self.params[fieldName].valType == 'code':
-                ctrls.valueCtrl.SetFont(self.app._codeFont)
+                try:
+                    ctrls.valueCtrl.SetFont(self.app._codeFont)
+                except:
+                    logging.error("Failed to set font {}"
+                                  .format(self.app._codeFont))
             elif self.params[fieldName].valType == 'str':
                 ctrls.valueCtrl.Bind(wx.EVT_KEY_UP, self.checkCodeWanted)
                 try:
@@ -780,10 +793,10 @@ class _BaseParamsDlg(wx.Dialog):
                     pass
 
         if fieldName in ['text']:
-            sizer.AddGrowableRow(currRow)  # doesn't seem to work though
-            # self.Bind(EVT_ETC_LAYOUT_NEEDED, self.onNewTextSize,
-            #    ctrls.valueCtrl)
+            sizer.AddGrowableRow(currRow)
             ctrls.valueCtrl.Bind(wx.EVT_KEY_UP, self.doValidate)
+        elif param.valType == 'fileList':
+            sizer.AddGrowableRow(currRow)  # doesn't seem to work though
         elif fieldName in ('color', 'fillColor', 'lineColor'):
             ctrls.valueCtrl.Bind(wx.EVT_RIGHT_DOWN, self.launchColorPicker)
         elif valType == 'extendedCode':
@@ -837,15 +850,16 @@ class _BaseParamsDlg(wx.Dialog):
             self.nameOKlabel.SetForegroundColour(wx.RED)
             self.mainSizer.Add(self.nameOKlabel, 0, flag=wx.ALIGN_CENTRE|wx.ALL, border=3)
         # add buttons for OK and Cancel
-        buttons = wx.StdDialogButtonSizer()
+        buttons = wx.BoxSizer(wx.HORIZONTAL)
         # help button if we know the url
         if self.helpUrl != None:
             helpBtn = wx.Button(self, wx.ID_HELP, _translate(" Help "))
             _tip = _translate("Go to online help about this component")
             helpBtn.SetToolTip(wx.ToolTip(_tip))
             helpBtn.Bind(wx.EVT_BUTTON, self.onHelp)
-            buttons.Add(helpBtn, 0, flag=wx.ALIGN_LEFT | wx.ALL, border=3)
-            buttons.AddSpacer(12)
+            buttons.Add(helpBtn, 0,
+                        flag=wx.LEFT | wx.ALL | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
         self.OKbtn = wx.Button(self, wx.ID_OK, _translate(" OK "))
         # intercept OK button if a loop dialog, in case file name was edited:
         if type(self) == DlgLoopProperties:
@@ -853,12 +867,27 @@ class _BaseParamsDlg(wx.Dialog):
         self.OKbtn.SetDefault()
 
         self.doValidate()  # disables OKbtn if bad name, syntax error, etc
-        buttons.Add(self.OKbtn, 0, wx.ALL, border=3)
         CANCEL = wx.Button(self, wx.ID_CANCEL, _translate(" Cancel "))
-        buttons.Add(CANCEL, 0, wx.ALL, border=3)
-        buttons.Realize()
+
+        buttons.AddStretchSpacer()
+        if sys.platform == 'darwin':
+            buttons.Add(CANCEL, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+            buttons.Add(self.OKbtn, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+        else:
+            buttons.Add(self.OKbtn, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+            buttons.Add(CANCEL, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                        border=3)
+
+        # buttons.Realize()
         # add to sizer
-        self.mainSizer.Add(buttons, flag=wx.ALIGN_RIGHT | wx.ALL, border=2)
+        self.mainSizer.Add(buttons, flag=wx.ALL | wx.EXPAND, border=3)
         self.SetSizerAndFit(self.mainSizer)
         self.mainSizer.Layout()
         # move the position to be v near the top of screen and
@@ -1096,14 +1125,14 @@ class _BaseParamsDlg(wx.Dialog):
             if used and not sameOldName:
                 msg = _translate(
                     "That name is in use (it's a %s). Try another name.")
-                return msg % namespace._localized[used], False
+                return msg % _translate(used), False
             elif not namespace.isValid(newName):  # valid as a var name
                 msg = _translate("Name must be alpha-numeric or _, no spaces")
                 return msg, False
             # warn but allow, chances are good that its actually ok
             elif namespace.isPossiblyDerivable(newName):
                 msg = namespace.isPossiblyDerivable(newName)
-                return namespace._localized[msg], True
+                return msg, True
             else:
                 return "", True
 
@@ -1262,9 +1291,9 @@ class DlgLoopProperties(_BaseParamsDlg):
                 dlg=self, parent=panel, label=label, fieldName=fieldName,
                 param=self.currentHandler.params[fieldName])
             panelSizer.Add(ctrls.nameCtrl, [row, 0], border=1,
-                           flag=wx.EXPAND | wx.ALIGN_CENTRE_VERTICAL | wx.ALL)
+                           flag=wx.EXPAND | wx.ALL)
             panelSizer.Add(ctrls.valueCtrl, [row, 1], border=1,
-                           flag=wx.EXPAND | wx.ALIGN_CENTRE_VERTICAL | wx.ALL)
+                           flag=wx.EXPAND | wx.ALL)
             row += 1
 
         self.globalCtrls['name'].valueCtrl.Bind(wx.EVT_TEXT, self.doValidate)
@@ -1313,6 +1342,7 @@ class DlgLoopProperties(_BaseParamsDlg):
                 self.Bind(wx.EVT_BUTTON, self.onBrowseTrialsFile,
                           ctrls.browseCtrl)
                 ctrls.valueCtrl.Bind(wx.EVT_RIGHT_DOWN, self.viewConditions)
+                ctrls.valueCtrl.Bind(wx.EVT_TEXT, self.doValidate)
                 panelSizer.Add(ctrls.nameCtrl, [row, 0])
                 panelSizer.Add(ctrls.valueCtrl, [row, 1])
                 panelSizer.Add(ctrls.browseCtrl, [row, 2])
@@ -1859,22 +1889,33 @@ class DlgExperimentProperties(_BaseParamsDlg):
         """
         # add buttons for help, OK and Cancel
         self.mainSizer = wx.BoxSizer(wx.VERTICAL)
-        buttons = wx.StdDialogButtonSizer()
+        buttons = wx.BoxSizer()
         if self.helpUrl is not None:
             helpBtn = wx.Button(self, wx.ID_HELP, _translate(" Help "))
             helpBtn.SetHelpText(_translate("Get help about this component"))
             helpBtn.Bind(wx.EVT_BUTTON, self.onHelp)
-            buttons.Add(helpBtn, 0, wx.ALIGN_RIGHT | wx.ALL, border=3)
+            buttons.Add(helpBtn, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, border=3)
+
         self.OKbtn = wx.Button(self, wx.ID_OK, _translate(" OK "))
         self.OKbtn.SetDefault()
-        buttons.Add(self.OKbtn, 0, wx.ALIGN_RIGHT | wx.ALL, border=3)
         CANCEL = wx.Button(self, wx.ID_CANCEL, _translate(" Cancel "))
-        buttons.Add(CANCEL, 0, wx.ALIGN_RIGHT | wx.ALL, border=3)
 
-        buttons.Realize()
-        self.ctrls.Fit()
+        buttons.AddStretchSpacer()
+        if sys.platform == 'darwin':
+            buttons.Add(CANCEL, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, border=3)
+            buttons.Add(self.OKbtn, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, border=3)
+        else:
+            buttons.Add(self.OKbtn, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, border=3)
+            buttons.Add(CANCEL, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, border=3)
+
         self.mainSizer.Add(self.ctrls, proportion=1, flag=wx.EXPAND)
-        self.mainSizer.Add(buttons, flag=wx.ALIGN_RIGHT)
+        self.mainSizer.Add(buttons, border=3,
+                           flag=wx.ALL | wx.RIGHT | wx.EXPAND)
         self.SetSizerAndFit(self.mainSizer)
 
         # move the position to be v near the top of screen and to the
@@ -1893,6 +1934,57 @@ class DlgExperimentProperties(_BaseParamsDlg):
             self.OK = False
         return wx.ID_OK
 
+class FileListCtrl(wx.ListBox):
+    def __init__(self, parent, choices=[], size=None, pathtype="rel"):
+        wx.ListBox.__init__(self)
+        parent.Bind(wx.EVT_DROP_FILES, self.addItem)
+        if type(choices) == str:
+            choices = data.utils.listFromString(choices)
+        self.Create(id=wx.ID_ANY, parent=parent, choices=choices, size=size, style=wx.LB_EXTENDED | wx.LB_HSCROLL)
+        # can now get/set things like self.parent
+        self.app = parent.app
+        self.builderFrame = self.GetTopLevelParent().frame
+        self.addBtn = wx.Button(parent, -1, style=wx.BU_EXACTFIT, label="+")
+        self.addBtn.Bind(wx.EVT_BUTTON, self.addItem)
+        self.subBtn = wx.Button(parent, -1, style=wx.BU_EXACTFIT, label="-")
+        self.subBtn.Bind(wx.EVT_BUTTON, self.removeItem)
+
+        self._szr = wx.BoxSizer(wx.HORIZONTAL)
+        self.btns = wx.BoxSizer(wx.VERTICAL)
+        self.btns.AddMany((self.addBtn, self.subBtn))
+        self._szr.Add(self, proportion=1, flag=wx.EXPAND)
+        self._szr.Add(self.btns)
+
+    def addItem(self, event):
+        if event.GetEventObject() == self.addBtn:
+            _wld = "Any file (*.*)|*"
+            dlg = wx.FileDialog(self, message=_translate("Specify file ..."),
+                                style=wx.FD_OPEN | wx.FD_FILE_MUST_EXIST | wx.FD_MULTIPLE,
+                                wildcard=_translate(_wld))
+            if dlg.ShowModal() != wx.ID_OK:
+                return 0
+            fileList = dlg.GetPaths()
+        else:
+            fileList = event.GetFiles()
+        relPaths = []
+        expFile = self.builderFrame.filename
+        folder = Path(expFile).parent
+        for filename in fileList:
+            relPaths.append(
+                os.path.relpath(filename, folder))
+        self.InsertItems(relPaths, 0)
+
+    def removeItem(self, event):
+        i = self.GetSelections()
+        if isinstance(i, int):
+            i = [i]
+        items = [item for index, item in enumerate(self.Items)
+                 if index not in i]
+        self.SetItems(items)
+
+    def GetValue(self):
+        return self.Items
+
 
 def _relpath(path, start='.'):
     """This code is based on os.path.relpath in the Python 2.6 distribution,
