@@ -6,4 +6,4 @@ Coder is the python IDE for PsychoPy
 """
 
 from __future__ import absolute_import, print_function
-from .coder import *  # pylint: disable=W0401
+from .coder import CoderFrame, BaseCodeEditor  # pylint: disable=W0401
