@@ -15,10 +15,12 @@ from psychopy import logging
 import psychopy
 from ...experiment import components
 import json
-from matplotlib import font_manager
+
+if sys.platform=='win32':
+    from matplotlib import font_manager
+    fm = font_manager.FontManager()
 
 thisFolder = Path(__file__).parent
-fm = font_manager.FontManager()
 iconsPath = Path(prefs.paths['resources'])
 
 try:
@@ -123,17 +125,10 @@ class ThemeMixin:
         # Define subfunctions to handle different object types
         def applyToToolbar(target):
             target.SetBackgroundColour(ThemeMixin.appColors['frame_bg'])
-            if sys.platform == 'win32':
-                # on mac ClearTools seg faults. Not sure what happens on linux
-                # Clear tools
-                target.ClearTools()
-                # Redraw tools
-                target.makeTools()
-            else:
-                # otherwise make the tools the first time but not again
-                if hasattr(target, '_needMakeTools') and target._needMakeTools:
-                    target.makeTools()
-                    self._needMakeTools = False
+            # Clear tools
+            target.ClearTools()
+            # Redraw tools
+            target.makeTools()
 
         def applyToStatusBar(target):
             target.SetBackgroundColour(cLib['white'])
@@ -144,6 +139,11 @@ class ThemeMixin:
             if hasattr(target, 'GetAuiManager'):
                 target.GetAuiManager().SetArtProvider(PsychopyDockArt())
                 target.GetAuiManager().Update()
+            for menu in target.GetMenuBar().GetMenus():
+                for submenu in menu[0].MenuItems:
+                    if isinstance(submenu.SubMenu, ThemeSwitcher):
+                        submenu.SubMenu._applyAppTheme()
+
 
         def applyToPanel(target):
             target.SetBackgroundColour(ThemeMixin.appColors['panel_bg'])
@@ -383,14 +383,14 @@ class ThemeMixin:
                  'break', 'local', 'global'],
                 0: ['NA']
             }
-        elif self.GetLexer == stc.STC_LEX_CPP:
+        elif self.GetLexer() == stc.STC_LEX_CPP:
             # C/C++
             keywords = baseC
             if hasattr(self, 'filename'):
                 if self.filename.endswith('.js'):
                     # JavaScript
                     keywords = {
-                        0: ['var', 'let', 'import', 'function', 'if', 'else', 'return', 'struct', 'for', 'while', 'do',
+                        0: ['var', 'const', 'let', 'import', 'function', 'if', 'else', 'return', 'struct', 'for', 'while', 'do',
                             'finally', 'throw', 'try', 'switch', 'case', 'break'],
                         1: ['null', 'false', 'true']
                     }
@@ -555,10 +555,11 @@ class ThemeMixin:
         else:
             finalFont = [wx.SystemSettings.GetFont(wx.SYS_ANSI_FIXED_FONT).GetFaceName()]
         # Cycle through font names, stop at first valid font
-        for font in fontList:
-            if fm.findfont(font) not in fm.defaultFont.values():
-                finalFont = [font] + bold + italic
-                break
+        if sys.platform == 'win32':
+            for font in fontList:
+                if fm.findfont(font) not in fm.defaultFont.values():
+                    finalFont = [font] + bold + italic
+                    break
 
         return ','.join(finalFont)
 
@@ -993,23 +994,29 @@ class ThemeSwitcher(wx.Menu):
         for theme in priority:
             tooltip = themeList.pop(theme)
             item = self.AppendRadioItem(wx.ID_ANY, _translate(theme), tooltip)
+            # Bind to theme change method
             frame.Bind(wx.EVT_MENU, frame.app.onThemeChange, item)
-            if item.ItemLabel.lower() == ThemeMixin.codetheme.lower():
-                item.Check(True)
-            else:
-                item.Check(False)
         # Make other theme buttons
         for theme in themeList:
             item = self.AppendRadioItem(wx.ID_ANY, _translate(theme), help=themeList[theme])
             frame.Bind(wx.EVT_MENU, frame.app.onThemeChange, item)
-            if item.ItemLabel.lower() == ThemeMixin.codetheme.lower():
-                item.Check(True)
-            else:
-                item.Check(False)
         self.AppendSeparator()
         # Add Theme Folder button
         item = self.Append(wx.ID_ANY, _translate("Open theme folder"))
         frame.Bind(wx.EVT_MENU, self.openThemeFolder, item)
 
     def openThemeFolder(self, event):
-        subprocess.call("explorer %(themes)s" % prefs.paths, shell=True)
+        # Choose a command according to OS
+        if sys.platform in ['win32']:
+            comm = "explorer"
+        elif sys.platform in ['darwin']:
+            comm = "open"
+        elif sys.platform in ['linux', 'linux2']:
+            comm = "dolphin"
+        # Use command to open themes folder
+        subprocess.call(f"{comm} {prefs.paths['themes']}", shell=True)
+
+    def _applyAppTheme(self):
+        for item in self.GetMenuItems():
+            if item.IsRadio():  # This means it will not attempt to check the separator
+                item.Check(item.ItemLabel.lower() == ThemeMixin.codetheme.lower())
