@@ -10,6 +10,7 @@ from builtins import range
 from past.builtins import basestring
 import os
 import re
+import ast
 import pickle
 import time
 import codecs
@@ -168,6 +169,33 @@ def indicesFromString(indsString):
         pass
 
 
+def listFromString(val):
+    """Take a string that looks like a list (with commas and/or [] and make
+    an actual python list"""
+    if type(val) == tuple:
+        return list(val)
+    elif type(val) == list:
+        return list(val)  # nothing to do
+    elif type(val) != str:
+        raise ValueError("_strToList requires a string as its input not {}"
+                         .format(repr(val)))
+    # try to evaluate with ast (works for "'yes,'no'" or "['yes', 'no']")
+    try:
+        iterable = ast.literal_eval(val)
+        if type(iterable) == tuple:
+            iterable = list(iterable)
+        return iterable
+    except (ValueError, SyntaxError):
+        pass  # e.g. "yes, no" won't work. We'll go on and try another way
+
+    val = val.strip()  # in case there are spaces
+    if val.startswith(('[', '(')) and val.endswith((']', ')')):
+        val = val[1:-1]
+    asList = val.split(",")
+    asList = [this.strip() for this in asList]
+    return asList
+
+
 def importConditions(fileName, returnFieldNames=False, selection=""):
     """Imports a list of conditions from an .xlsx, .csv, or .pkl file
 
@@ -201,7 +229,7 @@ def importConditions(fileName, returnFieldNames=False, selection=""):
         - "2:5"       # 2, 3, 4 (doesn't include last whole value)
         - "-10:2:"    # tenth from last to the last in steps of 2
         - slice(-10, 2, None)  # the same as above
-        - random(5) * 8  # five random vals 0-8
+        - random(5) * 8  # five random vals 0-7
 
     """
 
@@ -410,8 +438,10 @@ def importConditions(fileName, returnFieldNames=False, selection=""):
     elif len(selection) > 0:
         allConds = trialList
         trialList = []
+        print(selection)
+        print(len(allConds))
         for ii in selection:
-            trialList.append(allConds[int(round(ii))])
+            trialList.append(allConds[int(ii)])
 
     logging.exp('Imported %s as conditions, %d conditions, %d params' %
                 (fileName, len(trialList), len(fieldNames)))
