@@ -152,7 +152,7 @@ class Param(object):
                 return "%i" % self.val  # int and float -> str(int)
             except TypeError:
                 return "{}".format(self.val)  # try array of float instead?
-        elif self.valType in ['extendedStr','str']:
+        elif self.valType in ['extendedStr', 'str']:
             # at least 1 non-escaped '$' anywhere --> code wanted
             # return str if code wanted
             # return repr if str wanted; this neatly handles "it's" and 'He
@@ -160,7 +160,13 @@ class Param(object):
             if isinstance(self.val, basestring):
                 codeWanted = utils.unescapedDollarSign_re.search(self.val)
                 if codeWanted:
-                    return "%s" % getCodeFromParamStr(self.val)
+                    if utils.scriptTarget == 'PsychoJS':
+                        valJS = py2js.expression2js(self.val.strip('$'))
+                        if self.val != valJS:
+                            logging.debug("Rewriting with py2js: {} -> {}".format(self.val, valJS))
+                        return valJS
+                    else:
+                        return "%s" % getCodeFromParamStr(self.val)
                 else:  # str wanted
                     # remove \ from all \$
                     s = repr(re.sub(r"[\\]\$", '$', self.val))
@@ -238,7 +244,7 @@ def getCodeFromParamStr(val):
     out = re.sub(r"[\\]\$", '$', tmp2)  # remove \ from all \$
     if utils.scriptTarget=='PsychoJS':
         out = py2js.expression2js(out)
-    return out
+    return out if out else ''
 
 
 def toList(val):
