@@ -5,7 +5,7 @@
 """
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 
 from __future__ import absolute_import, division, print_function
@@ -25,6 +25,7 @@ try:
     haveSerial = True
 except Exception:
     haveSerial = False
+import errno
 import os
 import time
 import glob
@@ -33,7 +34,6 @@ import sys
 from copy import deepcopy, copy
 
 import numpy as np
-import scipy.optimize as optim
 from scipy import interpolate
 import json_tricks  # allows json to dump/load np.arrays and dates
 
@@ -63,8 +63,11 @@ else:
 if isinstance(monitorFolder, bytes):
     monitorFolder = monitorFolder.decode(sys.getfilesystemencoding())
 
-if not os.path.isdir(monitorFolder):
+try:
     os.makedirs(monitorFolder)
+except OSError as err:
+    if err.errno != errno.EEXIST:
+        raise
 
 
 class Monitor(object):
@@ -742,6 +745,7 @@ class GammaCalculator(object):
             -yVals are the measured luminances from a photometer/spectrometer
 
         """
+        import scipy.optimize as optim
         minGamma = 0.8
         maxGamma = 20.0
         gammaGuess = 2.0
