@@ -3,6 +3,7 @@
 
 import os
 import pytest
+import numpy as np
 from psychopy.data import utils
 from psychopy.constants import PY3
 from os.path import join
@@ -60,6 +61,17 @@ class Test_utilsClass:
             utils.importConditions(fileName_docx)
         assert ('Your conditions file should be an ''xlsx, csv, dlm, tsv or pkl file') == str(errMsg.value)
 
+        # test random selection of conditions
+        all_conditions = utils.importConditions(standard_files[0])
+        assert len(all_conditions) == 6
+        num_selected_conditions = 1001
+        selected_conditions = utils.importConditions(
+            standard_files[0],
+            selection=(np.concatenate(
+                ([0.9], np.random.random(num_selected_conditions - 1)*len(all_conditions)))))
+        assert selected_conditions[0] == expected_cond
+        assert len(selected_conditions) == num_selected_conditions
+
     def test_isValidVariableName(self):
         assert utils.isValidVariableName('Name') == (True, '')
         assert utils.isValidVariableName('a_b_c') == (True, '')
