@@ -6,7 +6,7 @@ independently controlled. Suitable for creating 'global form' stimuli or more
 detailed random dot stimuli."""
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 
 from __future__ import absolute_import, division, print_function
@@ -730,5 +730,8 @@ class ElementArrayStim(MinimalStim, TextureMixin):
         self.mask = value
 
     def __del__(self):
-        # remove textures from graphics card to prevent crash
-        self.clearTextures()
+        # remove textures from graphics card to prevent OpenGl memory leak
+        try:
+            self.clearTextures()
+        except ModuleNotFoundError:
+            pass  # has probably been garbage-collected already
