@@ -17,7 +17,7 @@ some more added:
 
 """
 import numpy as np
-import OpenGL.GL as gl
+from pyglet import gl
 
 from ..basevisual import BaseVisualStim, ColorMixin, ContainerMixin
 from psychopy.tools.attributetools import attributeSetter, setAttribute
@@ -131,12 +131,14 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
         self.opacity = opacity
         self.onTextCallback = onTextCallback
 
+        if units=='norm':
+            raise NotImplemented("TextBox2 doesn't support 'norm' units at the "
+                                 "moment. Use 'height' units instead")
         # first set params needed to create font (letter sizes etc)
         if letterHeight is None:
             self.letterHeight = defaultLetterHeight[self.units]
         else:
             self.letterHeight = letterHeight
-
         # self._pixLetterHeight helps get font size right but not final layout
         if 'deg' in self.units:  # treat deg, degFlat or degFlatPos the same
             scaleUnits = 'deg'  # scale units are just for font resolution
@@ -152,7 +154,7 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
         self.italic = italic
         self.lineSpacing = lineSpacing
         if padding is None:
-            padding = letterHeight / 2.0
+            padding = self.letterHeight / 2.0
         self.padding = padding
         self.glFont = None  # will be set by the self.font attribute setter
         self.font = font
@@ -201,13 +203,12 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
                 autoLog=False)
         self.pallette = { # If no focus
                 'lineColor': borderColor,
-                'lineRGB': self.box.lineRGB,
                 'lineWidth': borderWidth,
                 'fillColor': fillColor,
-                'fillRGB': self.box.fillRGB
         }
         # then layout the text (setting text triggers _layout())
-        self.text = text
+        self.startText = text
+        self.text = text if text is not None else ""
 
         # caret
         self.editable = editable
@@ -224,29 +225,10 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
 
     @pallette.setter
     def pallette(self, value):
-        pal = {}
-        # Double border width
-        if value['lineWidth']:
-            pal['lineWidth'] = max(value['lineWidth'], 2) * 2
-        else:
-            pal['lineWidth'] = 5 * 2
-        # Darken border
-        if value['lineColor']:
-            pal['lineRGB'] = pal['lineColor'] = [max(c - 0.05, 0.05) for c in value['lineRGB']]
-        else:
-            # Use window colour as base if border colour is none
-            pal['lineRGB'] = pal['lineColor'] = [max(c - 0.05, 0.05) for c in self.win.color]
-        # Lighten background
-        if value['fillColor']:
-            pal['fillRGB'] = pal['fillColor'] = [min(c + 0.05, 0.95) for c in value['fillRGB']]
-        else:
-            # Use window colour as base if fill colour is none
-            pal['fillRGB'] = pal['fillColor'] = [min(c + 0.05, 0.95) for c in self.win.color]
         self._pallette = {
             False: value,
-            True: pal
+            True: value
         }
-        print(self._pallette)
 
     @attributeSetter
     def font(self, fontName, italic=False, bold=False):
@@ -329,8 +311,8 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
         # then they are converted back during rendering using standard BaseStim
         vertices = np.zeros((len(text) * 4, 2), dtype=np.float32)
         self._charIndices = np.zeros((len(text)), dtype=int)
-        self._colors = np.zeros((len(text) * 4, 4), dtype=np.float32)
-        self._texcoords = np.zeros((len(text) * 4, 2), dtype=np.float32)
+        self._colors = np.zeros((len(text) * 4, 4), dtype=np.double)
+        self._texcoords = np.zeros((len(text) * 4, 2), dtype=np.double)
         self._glIndices = np.zeros((len(text) * 4), dtype=int)
 
         # the following are used internally for layout
@@ -491,9 +473,8 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
     def _getStartingVertices(self):
         """Returns vertices for a single non-printing char as a proxy
         (needed to get location for caret when there are no actual chars)"""
-        glyph = self.glFont["A"]  # just to get height
-        yTop = 0
-        yBot = yTop - glyph.size[1]
+        yTop = self._anchorOffsetY - (self.glFont.height - self.glFont.ascender) * self.lineSpacing
+        yBot = yTop - self._lineHeight
         x = 0
         theseVertices = np.array([[x, yTop], [x, yBot], [x, yBot], [x, yTop]])
         return theseVertices
@@ -504,10 +485,10 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
         self.box.setLineWidth(self.pallette['lineWidth']) # Use 1 as base if border width is none
         #self.borderWidth = self.box.lineWidth
         # Border colour
-        self.box.setLineColor(self.pallette['lineRGB'], colorSpace='rgb')
+        self.box.setLineColor(self.pallette['lineColor'], colorSpace='rgb')
         #self.borderColor = self.box.lineColor
         # Background
-        self.box.setFillColor(self.pallette['fillRGB'], colorSpace='rgb')
+        self.box.setFillColor(self.pallette['fillColor'], colorSpace='rgb')
         #self.fillColor = self.box.fillColor
 
         if self._needVertexUpdate:
@@ -529,16 +510,16 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
         gl.glEnableClientState(gl.GL_TEXTURE_COORD_ARRAY)
         gl.glEnableClientState(gl.GL_VERTEX_ARRAY)
 
-        gl.glVertexPointer(2, gl.GL_FLOAT, 0, self.verticesPix)
-        gl.glColorPointer(4, gl.GL_FLOAT, 0, self._colors)
-        gl.glTexCoordPointer(2, gl.GL_FLOAT, 0, self._texcoords)
+        gl.glVertexPointer(2, gl.GL_DOUBLE, 0, self.verticesPix.ctypes)
+        gl.glColorPointer(4, gl.GL_DOUBLE, 0, self._colors.ctypes)
+        gl.glTexCoordPointer(2, gl.GL_DOUBLE, 0, self._texcoords.ctypes)
 
         self.shader.bind()
         self.shader.setInt('texture', 0)
         self.shader.setFloat('pixel', [1.0 / 512, 1.0 / 512])
         nVerts = len(self.text)*4
-        gl.glDrawElements(gl.GL_QUADS, nVerts,
-                          gl.GL_UNSIGNED_INT, list(range(nVerts)))
+
+        gl.glDrawArrays(gl.GL_QUADS, 0, nVerts)
         self.shader.unbind()
 
         # removed the colors and font texture
@@ -556,6 +537,14 @@ class TextBox2(BaseVisualStim, ContainerMixin, ColorMixin):
 
         gl.glPopMatrix()
 
+    def reset(self):
+        # Reset contents
+        self.text = self.startText
+        # Make sure box is still editable (if needed)
+        if self.editable and self not in self.win._editableChildren:  # may yet gain focus if the first editable obj
+            self.win.addEditable(self)
+
+
     def contains(self, x, y=None, units=None, tight=False):
         """Returns True if a point x,y is inside the stimulus' border.
 
@@ -815,12 +804,13 @@ class Caret(ColorMixin):
             Caret colour
     """
 
-    def __init__(self, textbox, color, width):
+    def __init__(self, textbox, color, width, colorSpace='rgb'):
         self.textbox = textbox
         self.index = len(textbox.text)  # start off at the end
         self.autoLog = False
         self.width = width
         self.units = textbox.units
+        self.colorSpace = colorSpace
         self.color = color
 
     @attributeSetter
@@ -936,9 +926,9 @@ class Caret(ColorMixin):
         # lastChar = [bottLeft, topLeft, **bottRight**, **topRight**]
         ii = self.index
         if textbox.vertices.shape[0] == 0:
-            verts = self.textbox._getStartingVertices()
-            verts[:,1] = verts[:,1] / float(textbox._pixelScaling)
-            verts[:,1] = verts[:,1] + float(textbox._anchorOffsetY)
+            verts = textbox._getStartingVertices() / textbox._pixelScaling
+            verts[:,1] = verts[:,1]
+            verts[:,0] = verts[:,0] + float(textbox._anchorOffsetX)
         else:
             if self.index >= len(textbox._lineNs):  # caret is after last chr
                 chrVerts = textbox.vertices[range((ii-1) * 4, (ii-1) * 4 + 4)]
