@@ -56,7 +56,7 @@ Not implemented:
 """
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 #
 # VlcMovieStim contributed by Dan Fitch, April 2019.
@@ -615,7 +615,10 @@ class VlcMovieStim(BaseVisualStim, ContainerMixin):
                                level=logging.EXP, obj=self)
 
     def __del__(self):
-        self._unload()
+        try:
+            self._unload()
+        except ModuleNotFoundError:
+            pass  # has probably been garbage-collected already
 
     def setAutoDraw(self, val, log=None):
         """Add or remove a stimulus from the list of stimuli that will be
